==> fox-1.0.0.tar.gz: fox/src/Plugin/FoxCommand/FoxCommandGoto.php <==
<?php

namespace Drupal\fox\Plugin\FoxCommand;

/**
 * GOTO fox command.
 *
 * @FoxCommand(
 *   id = "goto",
 *   label = @Translation("Set context record. Usage: GOTO {TOP|BOTTOM|PREV|NEXT|number}")
 * )
 */
class FoxCommandGoto extends FoxCommandBaseClass {

  /**
   * {@inheritdoc}
   */
  public function execute(array $params, array $variables): array {
    $direction = reset($params);
    if (empty($direction)) {
      return $this->errorReturn($this->t('Empty parameter. Usage: GOTO {TOP|BOTTOM|PREV [step]|NEXT [step]|number}'));
    }

    $helper = $this->foxCommandsHelper();

    $entity_type = $variables['entity_type'] ?? NULL;
    if (empty($entity_type)) {
      return $this->errorReturn($this->t('Empty entity type. Use USE command.'));
    }
    $bundle = $variables['bundle'] ?? NULL;

    try {
      $query = $helper->getEntityQuery($entity_type, $bundle);

      $id_key = $helper->entityKey($entity_type, 'id');
      $query->sort($id_key);

      if (is_numeric($direction)) {
        $recno = $direction;
        $query->range($direction - 1, 1);
      }
      else {
        $directions = ['TOP', 'BOTTOM', 'PREV', 'NEXT'];
        $direction = strtoupper($direction);
        if (!in_array($direction, $directions)) {
          return $this->errorReturn($this->t('Wrong GOTO parameter: @direction', [
            '@direction' => $direction,
          ]));
        }

        if (in_array($direction, ['PREV', 'NEXT'])) {
          $recno = $variables['recno'] ?? NULL;
          if ($recno === NULL) {
            return $this->errorReturn($this->t('Empty current record number'));
          }

          $step = $params[1] ?? 1;
          if (!is_numeric($step)) {
            return $this->errorReturn($this->t('Step parameter @step is not numeric', [
              '@step' => $step,
            ]));
          }

          if ($direction === 'PREV') {
            $step *= -1;
          }

          $recno += $step;
          $query->range($recno - 1, 1);
        }
        else {
          $sort = ($direction === 'BOTTOM') ? 'DESC' : 'ASC';
          $query->sort($id_key, $sort);
          $query->range(0, 1);

          $recno = ($direction === 'BOTTOM') ? $variables['count'] : 1;
        }
      }

      $ids = $query->execute();
    }
    catch (\Exception $e) {
      return $this->errorReturn($this->t('Wrong parameter'));
    }

    if (empty($ids)) {
      return $this->errorReturn($this->t('Empty data'));
    }

    $id = reset($ids);
    return [
      'message' => dt('Set record to @recno', [
        '@recno' => $recno,
      ]),
      'variables' => [
        'id' => $id,
        'recno' => $recno,
      ],
    ];
  }

}

==> fox-1.1.1.tar.gz: fox/src/Plugin/FoxCommand/FoxCommandGoto.php <==
<?php

namespace Drupal\fox\Plugin\FoxCommand;

/**
 * GOTO fox command.
 *
 * @FoxCommand(
 *   id = "goto",
 *   label = @Translation("Set context record. Usage: GOTO {TOP|BOTTOM|PREV|NEXT|number}")
 * )
 */
class FoxCommandGoto extends FoxCommandBaseClass {

  const TOP = 'TOP';
  const BOTTOM = 'BOTTOM';
  const PREV = 'PREV';
  const NEXT = 'NEXT';

  /**
   * {@inheritdoc}
   */
  public function execute(array $params, array $variables): array {
    $direction = reset($params);
    if (empty($direction)) {
      return $this->errorReturn($this->t('Empty parameter. Usage: GOTO {TOP|BOTTOM|PREV [step]|NEXT [step]|number}'));
    }

    $helper = $this->foxCommandsHelper();

    $entity_type = $variables['entity_type'] ?? NULL;
    if (empty($entity_type)) {
      return $this->errorReturn($this->t('Empty entity type. Use USE command.'));
    }
    $bundle = $variables['bundle'] ?? NULL;

    try {
      $query = $helper->getEntityQuery($entity_type, $bundle);

      $id_key = $helper->entityKey($entity_type, 'id');
      $query->sort($id_key);

      if (is_numeric($direction)) {
        $recno = $direction;
        $query->range($direction - 1, 1);
      }
      else {
        $directions = [self::TOP, self::BOTTOM, self::PREV, self::NEXT];
        $direction = strtoupper($direction);
        if (!in_array($direction, $directions)) {
          return $this->errorReturn($this->t('Wrong GOTO parameter: @direction', [
            '@direction' => $direction,
          ]));
        }

        if (in_array($direction, [self::PREV, self::NEXT])) {
          $recno = $variables['recno'] ?? NULL;
          if ($recno === NULL) {
            return $this->errorReturn($this->t('Empty current record number'));
          }

          $step = $params[1] ?? 1;
          if (!is_numeric($step)) {
            return $this->errorReturn($this->t('Step parameter @step is not numeric', [
              '@step' => $step,
            ]));
          }

          if ($direction === self::PREV) {
            $step *= -1;
          }

          $recno += $step;
          $query->range($recno - 1, 1);
        }
        else {
          $sort = ($direction === self::BOTTOM) ? 'DESC' : 'ASC';
          $query->sort($id_key, $sort);
          $query->range(0, 1);

          $recno = ($direction === self::BOTTOM) ? $variables['count'] : 1;
        }
      }

      $ids = $query->execute();
    }
    catch (\Exception $e) {
      return $this->errorReturn($this->t('Wrong parameter'));
    }

    if (empty($ids)) {
      return $this->errorReturn($this->t('Empty data'));
    }

    $id = reset($ids);
    return [
      'message' => dt('Set record to @recno', [
        '@recno' => $recno,
      ]),
      'variables' => [
        'id' => $id,
        'recno' => $recno,
      ],
    ];
  }

}
